@@ -1,6 +1,8 @@
 #ifndef ALJOYSTICK_H
 #define ALJOYSTICK_H
+extern "C" {
 #include <linux/joystick.h>
+}
 #include "control.h"
 #include "point.h"
 
