@@ -13,7 +13,7 @@
 Keyboard::Keyboard() : Control()
 {
 	//calibrate();
-	left='z';right='x';up=';';down='.';fire1=' ';fire4='q';
+	left='z';right='x';up=';';down='.';fire1=' ';
 }
 
 int
@@ -55,8 +55,8 @@ Keyboard::fetch(void)
 		{
 			scount=0;
 			for(int i=0;i<FIRE4;i++)
-				last[i]=FALSE;
-			last[STRAIGHT]==TRUE;
+				last[i]=false;
+			last[STRAIGHT]=true;
 		}
 		else
 			scount++;
@@ -65,23 +65,25 @@ Keyboard::fetch(void)
 	{
 	scount=0;
 	for(int i=0;i<FIRE4;i++)
-		last[i]=FALSE;
+		last[i]=false;
 	if(key==right)
-		last[RIGHT]=TRUE;
+		last[RIGHT]=true;
 	else if(key==left)
-		last[LEFT]=TRUE;
+		last[LEFT]=true;
 	else if(key==down)
-		last[DOWN]=TRUE;
+		last[DOWN]=true;
 	else if(key==up)
-		last[UP]=TRUE;
+		last[UP]=true;
 	else if(key==fire1) 
-		last[FIRE1]=TRUE;
+		last[FIRE1]=true;
 	else if(key==fire2) 
-		last[FIRE2]=TRUE;
+		last[FIRE2]=true;
 	else if(key==fire3) 
-		last[FIRE4]=TRUE;
+		last[FIRE4]=true;
 	else if(key==fire4) 
-		last[FIRE4]=TRUE;
+		last[FIRE4]=true;
+	else if(key==27) 
+		last[QUIT]=true;
 	}
 }
 
