@@ -22,15 +22,16 @@ struct slotElt{
 };
 
 struct animElt{
+public:
 	int slot;
 	int duration;
 };
 
-typedef SLList<animElt> animList;
+typedef SLList<struct animElt> animList; 
 
-animElt animElt(int s, int d); 
-animList operator+(animList l, animElt a);
-animList operator+(animElt a, animElt b);
+struct animElt animElt(int s, int d); 
+animList operator+(animList l,struct animElt a);
+animList operator+(struct animElt a, struct animElt b);
 
 class
 Animation
