@@ -7,16 +7,20 @@
 Control::Control()
 {
 	for(int i=0;i<=FIRE4;i++)
-		last[i]=FALSE;
+		last[i]=false;
 }
 
 Control::Control(const Control &c)
 {
 	for(int i=0;i<=FIRE4;i++)
-		last[i]=FALSE;
+		last[i]=false;
 	copy(c);
 }
 
+Control::~Control()
+{
+}
+
 Control&
 Control::operator=(const Control &c)
 {
@@ -36,3 +40,15 @@ Control::copy(const Control& c)
 	for(int i=0;i<=FIRE4;i++)
 		last[i]=c.last[i];
 }
+
+bool
+Control::getRaw(void)
+{
+	return raw;
+}
+
+bool
+Control::getOkay(void)
+{
+	return okay;
+}
