@@ -1,9 +1,9 @@
 /*	Copyright Alex Hornby 1994/1995. All rights reserved.
  	See file README for details
 */
-
-#include "gif.h"
 #include "btypes.h"
+#include "palette.h"
+#include "gif.h"
 #include "asmblock.h"
 #include "screendefs.h"
 #include "alopen.h"
@@ -28,12 +28,12 @@ void fontinit(void)
 	byte	*t, *p;
 	Gif gif;
 	int w;
-	FILE* fp=alopen("./font.gif","/usr/local/lib/zapem/font.gif","rb");
+	FILE* fp=alopen("gfx/font.gif","rb");
 	gif.Load(fp);
 
 	t = fontptr = new byte [8192]; // reserve 8k
-	w=gif.GetWidth();
-	p=gif.GetPtr();
+	w=gif.getWidth();
+	p=gif.getPtr();
         int adj=w-8;
 
 	for(int c=0; c<31; c++)
