@@ -1,9 +1,9 @@
 #ifndef POINT_H
 #define POINT_H
 
-struct 
-point
+class point
 {
+public:
 	int x;
 	int y;
 };
