@@ -1,6 +1,8 @@
 #ifndef RND_H
 #define RND_H
 
+extern"C"{
 int rnd( int my_range);
+}
 
 #endif
